Available on crate feature
baking only.Expand description
This module contains the macros for creating the different structures and associated functions for any number of participants to simplify send/recv.
baking only.This module contains the macros for creating the different structures and associated functions for any number of participants to simplify send/recv.